Struct amazon_sp_fulfillment_inbound::models::inbound_shipment_info::InboundShipmentInfo
source · [−]pub struct InboundShipmentInfo {
pub shipment_id: Option<String>,
pub shipment_name: Option<String>,
pub ship_from_address: Box<Address>,
pub destination_fulfillment_center_id: Option<String>,
pub shipment_status: Option<ShipmentStatus>,
pub label_prep_type: Option<LabelPrepType>,
pub are_cases_required: bool,
pub confirmed_need_by_date: Option<String>,
pub box_contents_source: Option<BoxContentsSource>,
pub estimated_box_contents_fee: Option<Box<BoxContentsFeeDetails>>,
}Expand description
InboundShipmentInfo : Information about the seller’s inbound shipments. Returned by the listInboundShipments operation.
Fields
shipment_id: Option<String>The shipment identifier submitted in the request.
shipment_name: Option<String>The name for the inbound shipment.
ship_from_address: Box<Address>destination_fulfillment_center_id: Option<String>An Amazon fulfillment center identifier created by Amazon.
shipment_status: Option<ShipmentStatus>label_prep_type: Option<LabelPrepType>are_cases_required: boolIndicates whether or not an inbound shipment contains case-packed boxes. When AreCasesRequired = true for an inbound shipment, all items in the inbound shipment must be case packed.
confirmed_need_by_date: Option<String>box_contents_source: Option<BoxContentsSource>estimated_box_contents_fee: Option<Box<BoxContentsFeeDetails>>Implementations
sourceimpl InboundShipmentInfo
impl InboundShipmentInfo
sourcepub fn new(
ship_from_address: Address,
are_cases_required: bool
) -> InboundShipmentInfo
pub fn new(
ship_from_address: Address,
are_cases_required: bool
) -> InboundShipmentInfo
Information about the seller’s inbound shipments. Returned by the listInboundShipments operation.